<a id="mypy-boto3-iotanalytics"></a>

# mypy-boto3-iotanalytics

[![PyPI - types-aiobotocore-iotanalytics](https://img.shields.io/pypi/v/types-aiobotocore-iotanalytics.svg?color=blue)](https://pypi.org/project/types-aiobotocore-iotanalytics)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-iotanalytics.svg?color=blue)](https://pypi.org/project/types-aiobotocore-iotanalytics)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-iotanalytics?color=blue)](https://pypistats.org/packages/types-aiobotocore-iotanalytics)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.IoTAnalytics 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotanalytics.html#IoTAnalytics)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-iotanalytics docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_iotanalytics/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-iotanalytics](#mypy-boto3-iotanalytics)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `IoTAnalytics`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `IoTAnalytics` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[iotanalytics]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[iotanalytics]'

# standalone installation
python -m pip install types-aiobotocore-iotanalytics
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[iotanalytics]` in your environment:
  `python -m pip install 'types-aiobotocore[iotanalytics]'`

Both type checking and auto-complete should work for `IoTAnalytics` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[iotanalytics]` in your environment:
  `python -m pip install 'types-aiobotocore[iotanalytics]'`

Both type checking and auto-complete should work for `IoTAnalytics` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[iotanalytics]` in your environment:
  `python -m pip install 'types-aiobotocore[iotanalytics]'`
- Run `mypy` as usual

Type checking should work for `IoTAnalytics` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[iotanalytics]` in your environment:
  `python -m pip install 'types-aiobotocore[iotanalytics]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `IoTAnalytics` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`IoTAnalyticsClient` provides annotations for
`session.create_client("iotanalytics")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_iotanalytics import IoTAnalyticsClient

session = get_session()
async with session.create_client("iotanalytics") as client:
    client: IoTAnalyticsClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_iotanalytics.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_iotanalytics import IoTAnalyticsClient
from types_aiobotocore_iotanalytics.paginator import (
    ListChannelsPaginator,
    ListDatasetContentsPaginator,
    ListDatasetsPaginator,
    ListDatastoresPaginator,
    ListPipelinesPaginator,
)

session = get_session()
async with session.create_client("iotanalytics") as client:
    client: IoTAnalyticsClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
        list_dataset_contents_paginator: ListDatasetContentsPaginator = client.get_paginator("list_dataset_contents")
        list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
        list_datastores_paginator: ListDatastoresPaginator = client.get_paginator("list_datastores")
        list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
    ```







### Literals

`types_aiobotocore_iotanalytics.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_iotanalytics.literals import (
    ChannelStatusType,
    ComputeTypeType,
    DatasetActionTypeType,
    DatasetContentStateType,
    DatasetStatusType,
    DatastoreStatusType,
    FileFormatTypeType,
    ListChannelsPaginatorName,
    ListDatasetContentsPaginatorName,
    ListDatasetsPaginatorName,
    ListDatastoresPaginatorName,
    ListPipelinesPaginatorName,
    LoggingLevelType,
    ReprocessingStatusType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ChannelStatusType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_iotanalytics.type_defs` module contains structures and
shapes assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_iotanalytics.type_defs import (
    AddAttributesActivityTypeDef,
    BatchPutMessageErrorEntryTypeDef,
    BatchPutMessageRequestRequestTypeDef,
    BatchPutMessageResponseTypeDef,
    CancelPipelineReprocessingRequestRequestTypeDef,
    ChannelActivityTypeDef,
    ChannelMessagesTypeDef,
    ChannelStatisticsTypeDef,
    ChannelStorageSummaryTypeDef,
    ChannelStorageTypeDef,
    ChannelSummaryTypeDef,
    ChannelTypeDef,
    ColumnTypeDef,
    ContainerDatasetActionTypeDef,
    CreateChannelRequestRequestTypeDef,
    CreateChannelResponseTypeDef,
    CreateDatasetContentRequestRequestTypeDef,
    CreateDatasetContentResponseTypeDef,
    CreateDatasetRequestRequestTypeDef,
    CreateDatasetResponseTypeDef,
    CreateDatastoreRequestRequestTypeDef,
    CreateDatastoreResponseTypeDef,
    CreatePipelineRequestRequestTypeDef,
    CreatePipelineResponseTypeDef,
    CustomerManagedChannelS3StorageSummaryTypeDef,
    CustomerManagedChannelS3StorageTypeDef,
    CustomerManagedDatastoreS3StorageSummaryTypeDef,
    CustomerManagedDatastoreS3StorageTypeDef,
    DatasetActionSummaryTypeDef,
    DatasetActionTypeDef,
    DatasetContentDeliveryDestinationTypeDef,
    DatasetContentDeliveryRuleTypeDef,
    DatasetContentStatusTypeDef,
    DatasetContentSummaryTypeDef,
    DatasetContentVersionValueTypeDef,
    DatasetEntryTypeDef,
    DatasetSummaryTypeDef,
    DatasetTriggerTypeDef,
    DatasetTypeDef,
    DatastoreActivityTypeDef,
    DatastoreIotSiteWiseMultiLayerStorageSummaryTypeDef,
    DatastoreIotSiteWiseMultiLayerStorageTypeDef,
    DatastorePartitionTypeDef,
    DatastorePartitionsTypeDef,
    DatastoreStatisticsTypeDef,
    DatastoreStorageSummaryTypeDef,
    DatastoreStorageTypeDef,
    DatastoreSummaryTypeDef,
    DatastoreTypeDef,
    DeleteChannelRequestRequestTypeDef,
    DeleteDatasetContentRequestRequestTypeDef,
    DeleteDatasetRequestRequestTypeDef,
    DeleteDatastoreRequestRequestTypeDef,
    DeletePipelineRequestRequestTypeDef,
    DeltaTimeSessionWindowConfigurationTypeDef,
    DeltaTimeTypeDef,
    DescribeChannelRequestRequestTypeDef,
    DescribeChannelResponseTypeDef,
    DescribeDatasetRequestRequestTypeDef,
    DescribeDatasetResponseTypeDef,
    DescribeDatastoreRequestRequestTypeDef,
    DescribeDatastoreResponseTypeDef,
    DescribeLoggingOptionsResponseTypeDef,
    DescribePipelineRequestRequestTypeDef,
    DescribePipelineResponseTypeDef,
    DeviceRegistryEnrichActivityTypeDef,
    DeviceShadowEnrichActivityTypeDef,
    EstimatedResourceSizeTypeDef,
    FileFormatConfigurationTypeDef,
    FilterActivityTypeDef,
    GetDatasetContentRequestRequestTypeDef,
    GetDatasetContentResponseTypeDef,
    GlueConfigurationTypeDef,
    IotEventsDestinationConfigurationTypeDef,
    IotSiteWiseCustomerManagedDatastoreS3StorageSummaryTypeDef,
    IotSiteWiseCustomerManagedDatastoreS3StorageTypeDef,
    LambdaActivityTypeDef,
    LateDataRuleConfigurationTypeDef,
    LateDataRuleTypeDef,
    ListChannelsRequestRequestTypeDef,
    ListChannelsResponseTypeDef,
    ListDatasetContentsRequestRequestTypeDef,
    ListDatasetContentsResponseTypeDef,
    ListDatasetsRequestRequestTypeDef,
    ListDatasetsResponseTypeDef,
    ListDatastoresRequestRequestTypeDef,
    ListDatastoresResponseTypeDef,
    ListPipelinesRequestRequestTypeDef,
    ListPipelinesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    LoggingOptionsTypeDef,
    MathActivityTypeDef,
    MessageTypeDef,
    OutputFileUriValueTypeDef,
    PaginatorConfigTypeDef,
    ParquetConfigurationTypeDef,
    PartitionTypeDef,
    PipelineActivityTypeDef,
    PipelineSummaryTypeDef,
    PipelineTypeDef,
    PutLoggingOptionsRequestRequestTypeDef,
    QueryFilterTypeDef,
    RemoveAttributesActivityTypeDef,
    ReprocessingSummaryTypeDef,
    ResourceConfigurationTypeDef,
    ResponseMetadataTypeDef,
    RetentionPeriodTypeDef,
    RunPipelineActivityRequestRequestTypeDef,
    RunPipelineActivityResponseTypeDef,
    S3DestinationConfigurationTypeDef,
    SampleChannelDataRequestRequestTypeDef,
    SampleChannelDataResponseTypeDef,
    ScheduleTypeDef,
    SchemaDefinitionTypeDef,
    SelectAttributesActivityTypeDef,
    SqlQueryDatasetActionTypeDef,
    StartPipelineReprocessingRequestRequestTypeDef,
    StartPipelineReprocessingResponseTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TimestampPartitionTypeDef,
    TriggeringDatasetTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateChannelRequestRequestTypeDef,
    UpdateDatasetRequestRequestTypeDef,
    UpdateDatastoreRequestRequestTypeDef,
    UpdatePipelineRequestRequestTypeDef,
    VariableTypeDef,
    VersioningConfigurationTypeDef,
)

def get_structure() -> AddAttributesActivityTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-iotanalytics` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-iotanalytics docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_iotanalytics/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
